@@ -2,6 +2,7 @@
 import ctypes
 import os
 import time
+from typing import Tuple
 
 import numpy as np
 import tensorflow as tf
@@ -447,7 +448,7 @@ class Config(object):
         print(res)
         return res
 
-    def predict_triple(self, h, t, r, thresh=None):
+    def predict_triple(self, h, t, r):
         r'''This method tells you whether the given triple (h, t, r) is correct of wrong
 
         Args:
@@ -461,17 +462,9 @@ class Config(object):
             self.restore_tensorflow()
         res = self.test_step(np.array([h]), np.array([t]), np.array([r]))
         return res
-        if thresh != None:
-            if res < thresh:
-                print("triple (%d,%d,%d) is correct" % (h, t, r))
-            else:
-                print("triple (%d,%d,%d) is wrong" % (h, t, r))
-            return
-        self.lib.getValidBatch(self.valid_pos_h_addr, self.valid_pos_t_addr, self.valid_pos_r_addr, self.valid_neg_h_addr, self.valid_neg_t_addr, self.valid_neg_r_addr)
-        res_pos = self.test_step(self.valid_pos_h, self.valid_pos_t, self.valid_pos_r)
-        res_neg = self.test_step(self.valid_neg_h, self.valid_neg_t, self.valid_neg_r)
-        self.lib.getBestThreshold(self.relThresh_addr, res_pos.__array_interface__['data'][0], res_neg.__array_interface__['data'][0])
-        if res < self.relThresh[r]:
-            print("triple (%d,%d,%d) is correct" % (h, t, r))
-        else:
-            print("triple (%d,%d,%d) is wrong" % (h, t, r))
+
+    def predict_triples(self, triples: Tuple):
+        if self.importName != None:
+            self.restore_tensorflow()
+        res = self.test_step(np.array([triple[0] for triple in triples]), np.array([triple[1] for triple in triples]), np.array([triple[2] for triple in triples]))
+        return res
